==> njob-0.8.1.0-sources.jar: net/thevpc/nuts/toolbox/njob/JobAutoCompleter.java <==
/**
 * ====================================================================
 *            Nuts : Network Updatable Things Service
 *                  (universal package manager)
 * <br>
 * is a new Open Source Package Manager to help install packages and libraries
 * for runtime execution. Nuts is the ultimate companion for maven (and other
 * build managers) as it helps installing all package dependencies at runtime.
 * Nuts is not tied to java and is a good choice to share shell scripts and
 * other 'things' . Its based on an extensible architecture to help supporting a
 * large range of sub managers / repositories.
 * <br>
 *
 * Copyright [2020] [thevpc] Licensed under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 * <br> ====================================================================
 */
package net.thevpc.nuts.toolbox.njob;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import net.thevpc.nuts.NutsArgumentCandidate;
import net.thevpc.nuts.NutsCommandLine;
import net.thevpc.nuts.NutsDefaultCommandAutoComplete;
import net.thevpc.nuts.NutsSession;
import net.thevpc.nuts.NutsWorkspace;
import net.thevpc.nuts.NutsCommandAutoCompleteResolver;

/**
 *
 * @author vpc
 */
public class JobAutoCompleter implements NutsCommandAutoCompleteResolver {

    public JobAutoCompleter() {
    }

    @Override
    public List<NutsArgumentCandidate> resolveCandidates(NutsCommandLine commandline, int wordIndex, NutsSession session) {
        NutsWorkspace workspace = session.getWorkspace();
        JobServiceCmd fileContext = (JobServiceCmd) workspace.env().getProperty(JobServiceCmd.class.getName());
        NutsDefaultCommandAutoComplete autoComplete = new NutsDefaultCommandAutoComplete()
                .setSession(session)
                .setCurrentWordIndex(wordIndex)
                .setLine(commandline.toString()).setWords(
                Arrays.asList(commandline.toStringArray())
        );
        commandline.setAutoComplete(autoComplete);
        fileContext.runCommands(commandline);
        return autoComplete.getCandidates();
    }

}

==> njob-0.8.3.1-sources.jar: net/thevpc/nuts/toolbox/njob/JobAutoCompleter.java <==
/**
 * ====================================================================
 *            Nuts : Network Updatable Things Service
 *                  (universal package manager)
 * <br>
 * is a new Open Source Package Manager to help install packages and libraries
 * for runtime execution. Nuts is the ultimate companion for maven (and other
 * build managers) as it helps installing all package dependencies at runtime.
 * Nuts is not tied to java and is a good choice to share shell scripts and
 * other 'things' . Its based on an extensible architecture to help supporting a
 * large range of sub managers / repositories.
 * <br>
 *
 * Copyright [2020] [thevpc] Licensed under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 * <br> ====================================================================
 */
package net.thevpc.nuts.toolbox.njob;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import net.thevpc.nuts.*;

/**
 *
 * @author thevpc
 */
public class JobAutoCompleter implements NutsCommandAutoCompleteResolver {

    public JobAutoCompleter() {
    }

    @Override
    public List<NutsArgumentCandidate> resolveCandidates(NutsCommandLine commandline, int wordIndex, NutsSession session) {
        JobServiceCmd fileContext = (JobServiceCmd) session.env().getProperties().get(JobServiceCmd.class.getName());
        NutsDefaultCommandAutoComplete autoComplete = new NutsDefaultCommandAutoComplete()
                .setSession(session)
                .setCurrentWordIndex(wordIndex)
                .setLine(commandline.toString()).setWords(
                Arrays.asList(commandline.toStringArray())
        );
        commandline.setAutoComplete(autoComplete);
        fileContext.runCommands(commandline);
        return autoComplete.getCandidates();
    }

}
